use std::{sync::mpsc::Receiver};


#[cfg_attr(unix, path = "linux/mod.rs")]
#[cfg_attr(windows, path = "windows/mod.rs")]
#[cfg_attr(mac, path = "windows/mod.rs")]
pub mod platform_impl;

#[derive(Debug, Clone, Copy)]
pub struct Bounds {
    x: i32,
    y: i32,
    width: i32,
    height: i32,
}

#[derive(Debug, Clone, Copy)]
pub enum UnderlayEvent {
    Attach { bounds: Bounds, has_access: bool },
    Detach,
    MoveResize(Bounds),
    Focus,
    Blur,
}

pub fn register<T: Into<String>>(window_title: T) -> Receiver<UnderlayEvent> {
    let (tx,rx) = std::sync::mpsc::channel();

    platform_impl::init(window_title.into(), tx).expect("Catastrophe");

    return rx;
}



